@@ -24,44 +24,28 @@ from opentelemetry.sdk.trace.export import (
     ConsoleSpanExporter,
     SimpleSpanProcessor,
 )
+import sys
+from opentelemetry.sdk.resources import Resource
 
 from langtrace_python_sdk.extensions.langtrace_exporter import LangTraceExporter
-from langtrace_python_sdk.instrumentation.anthropic.instrumentation import (
+from langtrace_python_sdk.instrumentation import (
     AnthropicInstrumentation,
-)
-from langtrace_python_sdk.instrumentation.chroma.instrumentation import (
     ChromaInstrumentation,
-)
-from langtrace_python_sdk.instrumentation.cohere.instrumentation import (
     CohereInstrumentation,
-)
-from langtrace_python_sdk.instrumentation.groq.instrumentation import (
     GroqInstrumentation,
-)
-from langtrace_python_sdk.instrumentation.langchain.instrumentation import (
     LangchainInstrumentation,
-)
-from langtrace_python_sdk.instrumentation.langchain_community.instrumentation import (
     LangchainCommunityInstrumentation,
-)
-from langtrace_python_sdk.instrumentation.langchain_core.instrumentation import (
     LangchainCoreInstrumentation,
-)
-from langtrace_python_sdk.instrumentation.langgraph.instrumentation import (
     LanggraphInstrumentation,
-)
-from langtrace_python_sdk.instrumentation.llamaindex.instrumentation import (
     LlamaindexInstrumentation,
-)
-from langtrace_python_sdk.instrumentation.openai.instrumentation import (
     OpenAIInstrumentation,
-)
-from langtrace_python_sdk.instrumentation.pinecone.instrumentation import (
     PineconeInstrumentation,
-)
-from langtrace_python_sdk.instrumentation.qdrant.instrumentation import (
     QdrantInstrumentation,
+    WeaviateInstrumentation,
 )
+from opentelemetry.instrumentation.sqlalchemy import SQLAlchemyInstrumentor
+from colorama import Fore
+from langtrace_python_sdk.utils import check_if_sdk_is_outdated
 
 
 def init(
@@ -72,7 +56,9 @@ def init(
     api_host: Optional[str] = None,
     disable_instrumentations: Optional[DisableInstrumentations] = None,
 ):
-    provider = TracerProvider()
+    check_if_sdk_is_outdated()
+    print(Fore.GREEN + "Initializing Langtrace SDK.." + Fore.RESET)
+    provider = TracerProvider(resource=Resource.create({"service.name": sys.argv[0]}))
 
     remote_write_exporter = (
         LangTraceExporter(api_key=api_key, api_host=api_host)
@@ -84,26 +70,8 @@ def init(
     simple_processor_remote = SimpleSpanProcessor(remote_write_exporter)
     simple_processor_console = SimpleSpanProcessor(console_exporter)
 
-    if write_spans_to_console:
-        provider.add_span_processor(simple_processor_console)
-
-    elif custom_remote_exporter is not None:
-        if batch:
-            provider.add_span_processor(batch_processor_remote)
-        else:
-            provider.add_span_processor(simple_processor_remote)
-
-    elif api_host is not None:
-        if batch:
-            provider.add_span_processor(batch_processor_remote)
-        else:
-            provider.add_span_processor(simple_processor_remote)
-    else:
-        provider.add_span_processor(batch_processor_remote)
-
     # Initialize tracer
     trace.set_tracer_provider(provider)
-
     all_instrumentations = {
         "openai": OpenAIInstrumentation(),
         "groq": GroqInstrumentation(),
@@ -117,16 +85,38 @@ def init(
         "langgraph": LanggraphInstrumentation(),
         "anthropic": AnthropicInstrumentation(),
         "cohere": CohereInstrumentation(),
+        "weaviate": WeaviateInstrumentation(),
+        "sqlalchemy": SQLAlchemyInstrumentor(),
     }
 
     init_instrumentations(disable_instrumentations, all_instrumentations)
+    if write_spans_to_console:
+        print(Fore.BLUE + "Writing spans to console" + Fore.RESET)
+        provider.add_span_processor(simple_processor_console)
+
+    elif custom_remote_exporter is not None:
+        print(Fore.BLUE + "Exporting spans to custom remote exporter.." + Fore.RESET)
+        if batch:
+            provider.add_span_processor(batch_processor_remote)
+        else:
+            provider.add_span_processor(simple_processor_remote)
+
+    elif api_host is not None:
+        print(Fore.BLUE + f"Exporting spans to custom host: {api_host}.." + Fore.RESET)
+        if batch:
+            provider.add_span_processor(batch_processor_remote)
+        else:
+            provider.add_span_processor(simple_processor_remote)
+    else:
+        print(Fore.BLUE + "Exporting spans to Langtrace cloud.." + Fore.RESET)
+        provider.add_span_processor(batch_processor_remote)
 
 
 def init_instrumentations(
     disable_instrumentations: DisableInstrumentations, all_instrumentations: dict
 ):
     if disable_instrumentations is None:
-        for _, v in all_instrumentations.items():
+        for idx, (name, v) in enumerate(all_instrumentations.items()):
             v.instrument()
     else:
 
